#ifndef QUEUEELEMENT_H
#define QUEUEELEMENT_H

#include <QObject>
#include <QString>

class QueueElement : public QObject {
    Q_OBJECT

    public:
        QueueElement ();
        QueueElement (QString _url,QString _id="",QString _info="",int type = IMAGE);

        QString getID ();
        QString getURL ();
        QString getInfo();
        int getType ();

        void setID (QString);
        void setURL (QString);
        void setInfo (QString);
        void setType (int);

        enum request_type {IMAGE,LIST,DETAILS};

    private:
        QString url;
        QString id;
        QString info;
        int type;

    };
#endif // QUEUEELEMENT_H
